@@ -2,8 +2,9 @@ from typing import Tuple
 
 import click
 
-from ..decorators import loses_interactivity, require_login
-from ..helpers.global_options import GlobalOptions
+from sym.cli.decorators import loses_interactivity, require_login
+from sym.cli.helpers.global_options import GlobalOptions
+
 from ..helpers.options import resource_argument
 from .sym import sym
 
@@ -16,7 +17,7 @@ from .sym import sym
 @loses_interactivity
 def sym_exec(options: GlobalOptions, resource: str, command: Tuple[str, ...]) -> None:
     """Use approved creds for RESOURCE to execute COMMAND."""
-    from ..saml_clients.saml_client_factory import SAMLClientFactory
+    from sym.cli.saml_clients.saml_client_factory import SAMLClientFactory
 
     saml_client = SAMLClientFactory.create_saml_client(resource, options)
     saml_client.log_subprocess_event(command)
