@@ -57,7 +57,14 @@ def get_ansible_ssh_profile(client: SAMLClient):
 def aws_ssm_connection_plugin() -> Path:
     file = SymConfigFile(file_name=AWS_SSM_PATH, uid_scope=False)
     if not file.path.exists():
-        file.put(pkgutil.get_data(connection.__name__, file.path.name).decode("utf-8"))
+        try:
+            file.put(
+                pkgutil.get_data(connection.__name__, file.path.name).decode("utf-8")
+            )
+        except:
+            # PyOxidizer doesn't retain source files in some cases,
+            # so fall back to a (hopefully up-to-date) hard-coded source.
+            file.put(connection.sym_aws_ssm_source)
     return file.path
 
 
