@@ -2,67 +2,32 @@ import json
 import re
 import shlex
 from contextlib import contextmanager
-from functools import wraps
 from pathlib import Path
 from textwrap import dedent
 from typing import Dict, Sequence
 
 import boto3
 from botocore.config import Config as BotoConfig
-from botocore.exceptions import ClientError, ConnectionError, ProfileNotFound, WaiterError
+from botocore.exceptions import ClientError, WaiterError
+from sym.shared.cli.helpers.boto import make_intercept_boto_errors
 
 from ..decorators import retry
-from ..errors import (
-    AccessDenied,
-    BotoError,
-    CliError,
-    ExpiredCredentials,
-    OfflineError,
-    TargetNotConnected,
-    raise_if_match,
-)
+from ..errors import AccessDenied, ExpiredCredentials, TargetNotConnected
 from .config import SymConfigFile
 from .params import get_ssh_user
 
 InstanceIDPattern = re.compile("^i-[a-f0-9]+$")
-UnauthorizedError = re.compile(r"UnauthorizedOperation")
 RequestExpired = re.compile(r"RequestExpired|ExpiredToken")
 TargetNotConnectedPattern = re.compile("TargetNotConnected")
 AccessDeniedPattern = re.compile("AccessDeniedException")
 
-
-def intercept_boto_errors(f):
-    @wraps(f)
-    def wrapped(*args, **kwargs):
-        try:
-            return f(*args, **kwargs)
-        except ConnectionError as err:
-            raise OfflineError() from err
-        except ClientError as err:
-            if UnauthorizedError.search(str(err)):
-                raise BotoError(
-                    err, f"Does your user role have permission to {err.operation_name}?"
-                )
-
-            raise_if_match(
-                {
-                    TargetNotConnectedPattern: TargetNotConnected,
-                    AccessDeniedPattern: AccessDenied,
-                    RequestExpired: ExpiredCredentials,
-                },
-                str(err),
-            )
-
-            raise CliError(str(err)) from err
-        except ProfileNotFound as err:
-            raise BotoError(
-                err,
-                "AWS profile specified could not be found. "
-                "Please check your `AWS_PROFILE` environment variable and "
-                "your credentials file (default: $HOME/.aws/credentials).",
-            )
-
-    return wrapped
+intercept_boto_errors = make_intercept_boto_errors(
+    {
+        TargetNotConnectedPattern: TargetNotConnected,
+        AccessDeniedPattern: AccessDenied,
+        RequestExpired: ExpiredCredentials,
+    }
+)
 
 
 def boto_client(saml_client, service):
