@@ -2,9 +2,10 @@ import os
 import pty
 from typing import Sequence
 
-from sym.cli.helpers.contexts import push_envs
-from sym.cli.helpers.keywords_to_options import Argument, keywords_to_options
-from sym.cli.helpers.tee import Tee
+from sym.shared.cli.helpers.contexts import push_envs
+from sym.shared.cli.helpers.keywords_to_options import Argument, keywords_to_options
+from sym.shared.cli.helpers.tee import Tee
+
 from sym.cli.saml_clients.saml_client import SAMLClient
 
 
